@@ -19,8 +19,8 @@
 ;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 ;; USA
 
-;; Package-Version: 20250909.422
-;; Package-Revision: 8096ebd602f3
+;; Package-Version: 20251111.948
+;; Package-Revision: 3b11dd8ac7eb
 ;; Author: Sibi Prabakaran
 ;; Keywords: just justfile tools processes
 ;; URL: https://github.com/psibi/justl.el
@@ -505,6 +505,20 @@ They are returned as objects, as per the JSON output of \"just --dump\"."
   (when arg
     (cadr (s-split "--justfile=" arg))))
 
+(defvar-local justl--recipes nil
+  "Set of recipes loaded for `justl-exec-recipe-in-dir'")
+
+(defun justl-completion-annotation (candidate)
+  "Annotation function for `justl-exec-recipe-in-dir'."
+  (let* ((recipes justl--recipes)
+         (doc (cl-some
+               (lambda (recipe)
+                 (when (string= (justl--recipe-name recipe) candidate)
+                   (justl--recipe-desc recipe)))
+               recipes)))
+    (when doc
+      (concat  (propertize (concat " -- " doc) 'face 'font-lock-comment-face)))))
+
 ;;;###autoload
 (defun justl-exec-recipe-in-dir ()
   "Populate and execute the selected recipe."
@@ -512,9 +526,15 @@ They are returned as objects, as per the JSON output of \"just --dump\"."
   (let* ((justfile (justl--find-justfile default-directory)))
     (unless justfile
       (error "No justfile found"))
-    (let* ((recipes (justl--get-recipes justfile))
-           (recipe-name (completing-read "Recipes: "
-                                         (mapcar 'justl--recipe-name recipes)
+    (setq justl--recipes (justl--get-recipes justfile))
+    (let* ((recipes justl--recipes)
+           (recipe-names (mapcar 'justl--recipe-name justl--recipes))
+           (recipe-name (completing-read "Recipe: "
+                                         (lambda (string pred action)
+                                           (if (eq action 'metadata)
+                                               '(metadata (annotation-function . justl-completion-annotation)
+                                                          (category . just-recipe))
+                                             (complete-with-action action recipe-names string pred)))
                                          nil t nil nil))
            (recipe (justl--find-recipes recipes recipe-name)))
       (justl--exec-without-justfile
